@@ -9,8 +9,6 @@ import pymysql
 logger = logging.getLogger(__name__)
 
 
-DEFAULT_STATUS_FILE = "/var/run/replmon.status"
-DEFAULT_INTERVAL = 10
 
 
 class IsMaster(Exception):
@@ -20,10 +18,10 @@ class IsMaster(Exception):
 
 
 class Replmon(object):
-    def __init__(self, mysql_args):
+    def __init__(self, mysql_args, status_file, interval):
         self.mysql_args = mysql_args
-        self.status_file = DEFAULT_STATUS_FILE
-        self.interval = DEFAULT_INTERVAL
+        self.status_file = status_file
+        self.interval = interval
 
     def touch_status_file(self):
         if not os.path.exists(self.status_file):
