@@ -4,9 +4,10 @@ import logging
 import ConfigParser
 import os
 import pwd
+import stat
 
-import procname
 import daemon
+import procname
 import lockfile.pidlockfile
 
 from replmon import Replmon
@@ -18,7 +19,21 @@ logger.setLevel(logging.INFO)
 
 DEFAULT_CNF_FILE = "/etc/replmon.ini"
 DEFAULT_LOG_FILE = "/var/log/replmon.log"
+
 DEFAULT_PID_FILE = "/var/run/replmon/replmon.pid"
+DEFAULT_STATUS_FILE = "/var/run/replmon/replmon.status"
+
+DEFAULT_CHECK_INTERVAL = 10
+
+
+def ensure_writable(dir, uid, gid):
+    try:
+        os.mkdir(dir)
+    except OSError:
+        pass
+    os.chown(dir, uid, gid)
+    os.chmod(dir, stat.S_IWUSR)
+
 
 
 def main():
@@ -31,7 +46,7 @@ def main():
     parser.read(args.config)
 
     mysql_args = dict(parser.items("mysql"))
-    mon = Replmon(mysql_args)
+    mon = Replmon(mysql_args, DEFAULT_STATUS_FILE, DEFAULT_CHECK_INTERVAL)
 
     try:
         user = parser.get("system", "user")
@@ -41,18 +56,9 @@ def main():
         user_entry = pwd.getpwnam(user)
         uid, gid = user_entry.pw_uid, user_entry.pw_gid
 
-
     # Ensure we can touch the status file
-    mon.touch_status_file()
-    os.chown(mon.status_file, uid, gid)
-
-    # Ensure the pidfile folder exists and that we own it
-    pid_dir = os.path.dirname(DEFAULT_PID_FILE)
-    try:
-        os.mkdir(pid_dir)
-    except OSError:
-        pass
-    os.chown(pid_dir, uid, gid)
+    for dir in map(os.path.dirname, [DEFAULT_PID_FILE, DEFAULT_STATUS_FILE]):
+        ensure_writable(dir, uid, gid)
 
     formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
     file_handler = logging.FileHandler(DEFAULT_LOG_FILE)
